@@ -16,21 +16,21 @@ get_session('ctip://localhost:8099/',
 
   # リソースの送信
   session.resource('test.css') do |out|
-    FileUtils.copy_stream(File.open('data/test.css'), out)
+    copy_stream(File.open('data/test.css'), out)
   end
   
   session.set_continuous(true)
 
   # 文書の送信
   session.transcode do |out|
-    FileUtils.copy_stream(File.open('data/test.html'), out)
+    copy_stream(File.open('data/test.html'), out)
   end
 
   #リソースのアクセス許可
   session.property('input.include', 'http://copper-pdf.com/**')
     
   #文書の変換
-  session.transcodeServer('http://copper-pdf.com/')
+  session.transcode_server('http://copper-pdf.com/')
   
   # 結合
   session.join
