@@ -20,11 +20,11 @@ get_session('ctip://localhost:8099/',
   
   # リソースの送信
   session.resource('test.css') do |out|
-    FileUtils.copy_stream(File.open('data/test.css'), out)
+    copy_stream(File.open('data/test.css'), out)
   end
 
   # 文書の送信
   session.transcode do |out|
-    FileUtils.copy_stream(File.open('data/test.html'), out)
+    copy_stream(File.open('data/test.html'), out)
   end
 end
