@@ -21,5 +21,5 @@ get_session('ctip://localhost:8099/',
   session.property('input.include', 'http://www.w3.org/**')
     
   #文書の送信
-  session.transcodeServer('http://www.w3.org/TR/xslt');
+  session.transcode_server('http://www.w3.org/TR/xslt');
 end
