@@ -16,33 +16,33 @@ get_session('ctip://localhost:8099/',
 
   # リソースの送信
   session.resource('test.css') do |out|
-    FileUtils.copy_stream(File.open('data/test.css'), out)
+    copy_stream(File.open('data/test.css'), out)
   end
 
   # 文書の送信
   session.transcode('test.html') do |out|
-    FileUtils.copy_stream(File.open('data/test.html'), out)
+    copy_stream(File.open('data/test.html'), out)
   end
 
   # 事前に送って変換
   session.set_output_as_file('out/reset-2.pdf')
   session.resource('test.html') do |out|
-    FileUtils.copy_stream(File.open('data/test.html'), out)
+    copy_stream(File.open('data/test.html'), out)
   end
-  session.transcodeServer('test.html')
+  session.transcode_server('test.html')
   
   # 同じ文書を変換
   session.set_output_as_file('out/reset-3.pdf')
-  session.transcodeServer('test.html')
+  session.transcode_server('test.html')
   
   # リセットして変換
   session.reset
   session.set_output_as_file('out/reset-4.pdf')
-  session.transcodeServer('test.html')
+  session.transcode_server('test.html')
   
   # 再度変換
   session.set_output_as_file('out/reset-5.pdf')
   session.transcode('test.html') do |out|
-    FileUtils.copy_stream(File.open('data/test.html'), out)
+    copy_stream(File.open('data/test.html'), out)
   end
 end
