@@ -18,13 +18,13 @@ get_session('ctip://localhost:8099/',
   session.resolver do |uri, r|
     if File.exist?(uri)
       r.found do |out|
-        FileUtils.copy_stream(File.open(uri), out)
+        copy_stream(File.open(uri), out)
       end
     end
   end
 
   # 文書の送信
   session.transcode('data/test.html') do |out|
-    FileUtils.copy_stream(File.open('data/test.html'), out)
+    copy_stream(File.open('data/test.html'), out)
   end
 end
